.. redirect-from:: /users/prev_whats_new/github_stats_3.5.2

.. _github-stats-3-5-2:

GitHub statistics for 3.5.2 (May 02, 2022)
==========================================

GitHub statistics for 2021/12/11 (tag: v3.5.1) - 2022/05/02

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 61 issues and merged 222 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/69?closed=1>`__

The following 30 authors contributed 319 commits.

* Adeel Hassan
* Aitik Gupta
* Andrew Fennell
* andrzejnovak
* Antony Lee
* Clément Phan
* daniilS
* David Poznik
* David Stansby
* dependabot[bot]
* Edouard Berthe
* Elliott Sales de Andrade
* Greg Lucas
* Hassan Kibirige
* Jake VanderPlas
* Jay Stanley
* Jody Klymak
* MAKOMO
* Matthias Bussonnier
* Niyas Sait
* Oscar Gustafsson
* Pieter P
* Qijia Liu
* Quentin Peter
* Raphael Quast
* richardsheridan
* root
* Steffen Rehberg
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (222):

* :ghpull:`22963`: Backport PR #22957 on branch v3.5.x (fix "is" comparison for np.array)
* :ghpull:`22951`: Backport PR #22946: FIX: Handle no-offsets in collection datalim
* :ghpull:`22957`: fix "is" comparison for np.array
* :ghpull:`22962`: Backport PR #22961 on branch v3.5.x (Raised macosx memory leak threshold)
* :ghpull:`22961`: Raised macosx memory leak threshold
* :ghpull:`22945`: FIX: Handle no-offsets in collection datalim
* :ghpull:`22946`: FIX: Handle no-offsets in collection datalim (alternative)
* :ghpull:`22944`: Backport PR #22907 on branch v3.5.x (Fix quad mesh cursor data)
* :ghpull:`22943`: Backport PR #22923 on branch v3.5.x (Fixed _upcast_err docstring and comments in _axes.py)
* :ghpull:`22907`: Fix quad mesh cursor data
* :ghpull:`22923`: Fixed _upcast_err docstring and comments in _axes.py
* :ghpull:`22876`: Backport PR #22560 on branch v3.5.x (Improve pandas/xarray/... conversion)
* :ghpull:`22942`: Backport PR #22933 on branch v3.5.x (Adjusted wording in pull request guidelines)
* :ghpull:`22941`: Backport PR #22898 on branch v3.5.x (Only set Tk scaling-on-map for Windows systems)
* :ghpull:`22935`: Backport PR #22002: Fix TkAgg memory leaks and test for memory growth regressions
* :ghpull:`22898`: Only set Tk scaling-on-map for Windows systems
* :ghpull:`22933`: Adjusted wording in pull request guidelines
* :ghpull:`22002`: Fix TkAgg memory leaks and test for memory growth regressions
* :ghpull:`22924`: Fix gtk4 incorrect import.
* :ghpull:`22922`: Backport PR #22904 on branch v3.5.x (Fixed typo in triage acknowledgment)
* :ghpull:`22904`: Fixed typo in triage acknowledgment
* :ghpull:`22890`: DOC: add ipykernel to list of optional dependencies
* :ghpull:`22878`: Backport PR #22871 on branch v3.5.x (Fix year offset not always being added)
* :ghpull:`22871`: Fix year offset not always being added
* :ghpull:`22844`: Backport PR #22313 on branch v3.5.x (Fix colorbar exponents)
* :ghpull:`22560`: Improve pandas/xarray/... conversion
* :ghpull:`22846`: Backport PR #22284 on branch v3.5.x (Specify font number for TTC font subsetting)
* :ghpull:`22284`: Specify font number for TTC font subsetting
* :ghpull:`22845`: Backport PR #22199 on branch v3.5.x (DOC: git:// is deprecated.)
* :ghpull:`22837`: Backport PR #22807 on branch v3.5.x (Replace quiver dpi callback with reinit-on-dpi-changed.)
* :ghpull:`22838`: Backport PR #22806 on branch v3.5.x (FIX: callback for subfigure uses parent)
* :ghpull:`22832`: Backport PR #22767 on branch v3.5.x (Fixed bug in find_nearest_contour)
* :ghpull:`22767`: Fixed bug in find_nearest_contour
* :ghpull:`22807`: Replace quiver dpi callback with reinit-on-dpi-changed.
* :ghpull:`22806`: FIX: callback for subfigure uses parent
* :ghpull:`22737`: Backport PR #22138: Fix clearing subfigures
* :ghpull:`22735`: MNT: prefer Figure.clear() as canonical over Figure.clf()
* :ghpull:`22783`: Backport PR #22732: FIX: maybe improve renderer dance
* :ghpull:`22748`: Backport PR #22628 on branch v3.5.x (Add RuntimeWarning guard around division-by-zero)
* :ghpull:`22732`: FIX: maybe improve renderer dance
* :ghpull:`22764`: Backport PR #22756 on branch v3.5.x (Use system distutils instead of the setuptools copy)
* :ghpull:`22780`: Backport PR #22766 on branch v3.5.x (FIX: account for constant deprecations in Pillow 9.1)
* :ghpull:`22781`: Backport PR #22776 on branch v3.5.x (Fix colorbar stealing from a single axes and with panchor=False.)
* :ghpull:`22782`: Backport PR #22774 on branch v3.5.x (Remove outdated doc for pie chart)
* :ghpull:`22774`: Remove outdated doc for pie chart
* :ghpull:`22776`: Fix colorbar stealing from a single axes and with panchor=False.
* :ghpull:`22766`: FIX: account for deprecations of constant in Pillow 9.1
* :ghpull:`22756`: Use system distutils instead of the setuptools copy
* :ghpull:`22750`: Backport PR #22743: Fix configure_subplots with tool manager
* :ghpull:`22743`: Fix configure_subplots with tool manager
* :ghpull:`22628`: Add RuntimeWarning guard around division-by-zero
* :ghpull:`22736`: Backport PR #22719 on branch v3.5.x (Fix incorrect deprecation warning)
* :ghpull:`22719`: Fix incorrect deprecation warning
* :ghpull:`22138`: Fix clearing subfigures
* :ghpull:`22729`: Backport PR #22711 on branch v3.5.x (RangeSlider handle set_val bugfix)
* :ghpull:`22711`: RangeSlider handle set_val bugfix
* :ghpull:`22701`: Backport PR #22691 on branch v3.5.x (FIX: remove toggle on QuadMesh cursor data)
* :ghpull:`22723`: Backport PR #22716 on branch v3.5.x (DOC: set canonical)
* :ghpull:`22703`: Backport PR #22689 on branch v3.5.x (Fix path_effects to work on text with spaces only)
* :ghpull:`22689`: Fix path_effects to work on text with spaces only
* :ghpull:`22691`: FIX: remove toggle on QuadMesh cursor data
* :ghpull:`22696`: Backport PR #22693 on branch v3.5.x (Remove QuadMesh from mouseover set.)
* :ghpull:`22693`: Remove QuadMesh from mouseover set.
* :ghpull:`22647`: Backport PR #22429 on branch v3.5.x (Enable windows/arm64 platform)
* :ghpull:`22653`: Simplify FreeType version check to avoid packaging
* :ghpull:`22646`: Manual backport of pr 22635 on v3.5.x
* :ghpull:`22429`: Enable windows/arm64 platform
* :ghpull:`22635`: FIX: Handle inverted colorbar axes with extensions
* :ghpull:`22313`: Fix colorbar exponents
* :ghpull:`22619`: Backport PR #22611 on branch v3.5.x (FIX: Colorbars check for subplotspec attribute before using)
* :ghpull:`22618`: Backport PR #22617 on branch v3.5.x (Bump actions/checkout from 2 to 3)
* :ghpull:`22611`: FIX: Colorbars check for subplotspec attribute before using
* :ghpull:`22617`: Bump actions/checkout from 2 to 3
* :ghpull:`22595`: Backport PR #22005: Further defer backend selection
* :ghpull:`22602`: Backport PR #22596 on branch v3.5.x (Fix backend in matplotlibrc if unset in mplsetup.cfg)
* :ghpull:`22596`: Fix backend in matplotlibrc if unset in mplsetup.cfg
* :ghpull:`22597`: Backport PR #22594 on branch v3.5.x (FIX: do not pass dashes to collections in errorbar)
* :ghpull:`22594`: FIX: do not pass dashes to collections in errorbar
* :ghpull:`22593`: Backport PR #22559 on branch v3.5.x (fix: fill stairs should have lw=0 instead of edgecolor="none")
* :ghpull:`22005`: Further defer backend selection
* :ghpull:`22559`: fix: fill stairs should have lw=0 instead of edgecolor="none"
* :ghpull:`22592`: Backport PR #22141 on branch v3.5.x (Fix check 1d)
* :ghpull:`22141`: Fix check 1d
* :ghpull:`22588`: Backport PR #22445 on branch v3.5.x (Fix loading tk on windows when current process has >1024 modules.)
* :ghpull:`22445`: Fix loading tk on windows when current process has >1024 modules.
* :ghpull:`22575`: Backport PR #22572 on branch v3.5.x (Fix issue with unhandled Done exception)
* :ghpull:`22578`: Backport PR #22038 on branch v3.5.x (DOC: Include alternatives to deprecations in the documentation)
* :ghpull:`22572`: Fix issue with unhandled Done exception
* :ghpull:`22557`: Backport PR #22549 on branch v3.5.x (Really fix wheel building on CI)
* :ghpull:`22549`: Really fix wheel building on CI
* :ghpull:`22548`: Backport PR #22540 on branch v3.5.x (Reorder text api docs.)
* :ghpull:`22540`: Reorder text api docs.
* :ghpull:`22542`: Backport PR #22534 on branch v3.5.x (Fix issue with manual clabel)
* :ghpull:`22534`: Fix issue with manual clabel
* :ghpull:`22501`: Backport PR #22499 on branch v3.5.x (FIX: make the show API on webagg consistent with others)
* :ghpull:`22499`: FIX: make the show API on webagg consistent with others
* :ghpull:`22500`: Backport PR #22496 on branch v3.5.x (Fix units in quick start example)
* :ghpull:`22496`: Fix units in quick start example
* :ghpull:`22493`: Backport PR #22483 on branch v3.5.x (Tweak arrow demo size.)
* :ghpull:`22492`: Backport PR #22476: FIX: Include (0, 0) offsets in scatter autoscaling
* :ghpull:`22483`: Tweak arrow demo size.
* :ghpull:`22476`: FIX: Include (0, 0) offsets in scatter autoscaling
* :ghpull:`22481`: Backport PR #22479 on branch v3.5.x (adds _enum qualifier for QColorDialog.ShowAlphaChannel. Closes #22471.)
* :ghpull:`22479`: adds _enum qualifier for QColorDialog.ShowAlphaChannel. Closes #22471.
* :ghpull:`22475`: Backport PR #22474 on branch v3.5.x (Clarify secondary_axis documentation)
* :ghpull:`22474`: Clarify secondary_axis documentation
* :ghpull:`22462`: Backport PR #22458 on branch v3.5.x (Fix Radar Chart Gridlines for Non-Circular Charts)
* :ghpull:`22456`: Backport PR #22375 on branch v3.5.x (Re-enable cibuildwheel on push)
* :ghpull:`22375`: Re-enable cibuildwheel on push
* :ghpull:`22443`: Backport PR #22442 on branch v3.5.x (CI: skip test to work around gs bug)
* :ghpull:`22442`: CI: skip test to work around gs bug
* :ghpull:`22441`: Backport PR #22434 on branch v3.5.x (DOC: imbalanced backticks.)
* :ghpull:`22436`: Backport PR #22431 on branch v3.5.x (Update Scipy intersphinx inventory link)
* :ghpull:`22438`: Backport PR #22430 on branch v3.5.x (fix method name in doc)
* :ghpull:`22434`: DOC: imbalanced backticks.
* :ghpull:`22426`: Backport PR #22398 on branch v3.5.x (Pin coverage to fix CI)
* :ghpull:`22428`: Backport PR #22368 on branch v3.5.x (Pin dependencies to fix CI)
* :ghpull:`22427`: Backport PR #22396 on branch v3.5.x (Clarify note in get_cmap())
* :ghpull:`22396`: Clarify note in get_cmap()
* :ghpull:`22398`: Pin coverage to fix CI
* :ghpull:`22368`: Pin dependencies to fix CI
* :ghpull:`22358`: Backport PR #22349 on branch v3.5.x (Use latex as the program name for kpsewhich)
* :ghpull:`22349`: Use latex as the program name for kpsewhich
* :ghpull:`22348`: Backport PR #22346 on branch v3.5.x (Remove invalid ``</input>`` tag in ``animation.HTMLWriter``)
* :ghpull:`22346`: Remove invalid ``</input>`` tag in ``animation.HTMLWriter``
* :ghpull:`22328`: Backport PR #22288 on branch v3.5.x (update documentation after #18966)
* :ghpull:`22288`: update documentation after #18966
* :ghpull:`22325`: Backport PR #22283: Fixed ``repr`` for ``SecondaryAxis``
* :ghpull:`22322`: Backport PR #22077 on branch v3.5.x (Fix keyboard event routing in Tk backend (fixes #13484, #14081, and #22028))
* :ghpull:`22321`: Backport PR #22290 on branch v3.5.x (Respect ``position`` and ``group`` argument in Tk toolmanager add_toolitem)
* :ghpull:`22318`: Backport PR #22293 on branch v3.5.x (Modify example for x-axis tick labels at the top)
* :ghpull:`22319`: Backport PR #22279 on branch v3.5.x (Remove Axes sublists from docs)
* :ghpull:`22327`: Backport PR #22326 on branch v3.5.x (CI: ban coverage 6.3 that may be causing random hangs in fork test)
* :ghpull:`22326`: CI: ban coverage 6.3 that may be causing random hangs in fork test
* :ghpull:`22077`: Fix keyboard event routing in Tk backend (fixes #13484, #14081, and #22028)
* :ghpull:`22290`: Respect ``position`` and ``group`` argument in Tk toolmanager add_toolitem
* :ghpull:`22293`: Modify example for x-axis tick labels at the top
* :ghpull:`22311`: Backport PR #22285 on branch v3.5.x (Don't warn on grid removal deprecation if grid is hidden)
* :ghpull:`22310`: Backport PR #22294 on branch v3.5.x (Add set_cursor method to FigureCanvasTk)
* :ghpull:`22285`: Don't warn on grid removal deprecation if grid is hidden
* :ghpull:`22294`: Add set_cursor method to FigureCanvasTk
* :ghpull:`22309`: Backport PR #22301 on branch v3.5.x (FIX: repositioning axes labels: use get_window_extent instead for spines.)
* :ghpull:`22301`: FIX: repositioning axes labels: use get_window_extent instead for spines.
* :ghpull:`22307`: Backport PR #22306 on branch v3.5.x (FIX: ensure that used sub-packages are actually imported)
* :ghpull:`22306`: FIX: ensure that used sub-packages are actually imported
* :ghpull:`22283`: Fixed ``repr`` for ``SecondaryAxis``
* :ghpull:`22275`: Backport PR #22254 on branch v3.5.x (Disable QuadMesh cursor data by default)
* :ghpull:`22254`: Disable QuadMesh cursor data by default
* :ghpull:`22269`: Backport PR #22265 on branch v3.5.x (Fix Qt enum access.)
* :ghpull:`22265`: Fix Qt enum access.
* :ghpull:`22259`: Backport PR #22256 on branch v3.5.x (Skip tests on the -doc branches)
* :ghpull:`22238`: Backport PR #22235 on branch v3.5.x (Run wheel builds on PRs when requested by a label)
* :ghpull:`22241`: Revert "Backport PR #22179 on branch v3.5.x (FIX: macosx check case-insensitive app name)"
* :ghpull:`22248`: Backport PR #22206 on branch v3.5.x (Improve formatting of "Anatomy of a figure")
* :ghpull:`22235`: Run wheel builds on PRs when requested by a label
* :ghpull:`22206`: Improve formatting of "Anatomy of a figure"
* :ghpull:`22220`: Backport PR #21833: Enforce backport conditions on v*-doc branches
* :ghpull:`22219`: Backport PR #22218 on branch v3.5.x (Fix typo in ``tutorials/intermediate/arranging_axes.py``)
* :ghpull:`22218`: Fix typo in ``tutorials/intermediate/arranging_axes.py``
* :ghpull:`22217`: Backport PR #22209 on branch v3.5.x (DOC: Document default join style)
* :ghpull:`22209`: DOC: Document default join style
* :ghpull:`22214`: Backport PR #22208 on branch v3.5.x (Stop sorting artists in Figure Options dialog)
* :ghpull:`22215`: Backport PR #22177 on branch v3.5.x (Document ArtistList)
* :ghpull:`22177`: Document ArtistList
* :ghpull:`22208`: Stop sorting artists in Figure Options dialog
* :ghpull:`22199`: DOC: git:// is deprecated.
* :ghpull:`22210`: Backport PR #22202 on branch v3.5.x (PR: Fix merge of 18966)
* :ghpull:`22202`: PR: Fix merge of 18966
* :ghpull:`22201`: Backport PR #22053 on branch v3.5.x (DOC: Document default cap styles)
* :ghpull:`22053`: DOC: Document default cap styles
* :ghpull:`22195`: Backport PR #22179 on branch v3.5.x (FIX: macosx check case-insensitive app name)
* :ghpull:`22192`: Backport PR #22190 on branch v3.5.x (DOC: Fix upstream URL for merge in CircleCI)
* :ghpull:`22188`: Backport PR #22187 on branch v3.5.x (Fix typo in ``axhline`` docstring)
* :ghpull:`22187`: Fix typo in ``axhline`` docstring
* :ghpull:`22185`: Backport PR #22184 on branch v3.5.x (Removed dev from 3.10-version)
* :ghpull:`22186`: Backport PR #21943 on branch v3.5.x (DOC: explain too many ticks)
* :ghpull:`21943`: DOC: explain too many ticks
* :ghpull:`22184`: Removed dev from 3.10-version
* :ghpull:`22168`: Backport PR #22144 on branch v3.5.x (Fix cl subgridspec)
* :ghpull:`22144`: Fix cl subgridspec
* :ghpull:`22155`: Backport PR #22082 on branch v3.5.x (Update both zoom/pan states on wx when triggering from keyboard.)
* :ghpull:`22082`: Update both zoom/pan states on wx when triggering from keyboard.
* :ghpull:`22153`: Backport PR #22147 on branch v3.5.x (Fix loading user-defined icons for Tk toolbar)
* :ghpull:`22152`: Backport PR #22135 on branch v3.5.x (Fix loading user-defined icons for Qt plot window)
* :ghpull:`22151`: Backport PR #22078 on branch v3.5.x (Prevent tooltips from overlapping buttons in NavigationToolbar2Tk (fixes issue mentioned in #22028))
* :ghpull:`22135`: Fix loading user-defined icons for Qt plot window
* :ghpull:`22078`: Prevent tooltips from overlapping buttons in NavigationToolbar2Tk (fixes issue mentioned in #22028)
* :ghpull:`22147`: Fix loading user-defined icons for Tk toolbar
* :ghpull:`22136`: Backport PR #22132 on branch v3.5.x (TST: Increase fp tolerances for some images)
* :ghpull:`22132`: TST: Increase fp tolerances for some images
* :ghpull:`22121`: Backport PR #22116 on branch v3.5.x (FIX: there is no add_text method, fallback to add_artist)
* :ghpull:`22117`: Backport PR #21860 on branch v3.5.x (DOC: Update style sheet reference)
* :ghpull:`22116`: FIX: there is no add_text method, fallback to add_artist
* :ghpull:`22038`: DOC: Include alternatives to deprecations in the documentation
* :ghpull:`22074`: Backport PR #22066 on branch v3.5.x (FIX: Remove trailing zeros from offset significand)
* :ghpull:`22106`: Backport PR #22089: FIX: squash memory leak in colorbar
* :ghpull:`22089`: FIX: squash memory leak in colorbar
* :ghpull:`22101`: Backport PR #22099 on branch v3.5.x (CI: Disable numpy avx512 instructions)
* :ghpull:`22099`: CI: Disable numpy avx512 instructions
* :ghpull:`22095`: Backport PR #22083 on branch v3.5.x (Fix reference to Matplotlib FAQ in doc/index.rst)
* :ghpull:`22066`: FIX: Remove trailing zeros from offset significand
* :ghpull:`22072`: Backport PR #22071 on branch v3.5.x (Fix a small typo in docstring ("loation" --> "location"))
* :ghpull:`22071`: Fix a small typo in docstring ("loation" --> "location")
* :ghpull:`22070`: Backport PR #22069 on branch v3.5.x ([Doc] Fix typo in ``units.py`` documentation example)
* :ghpull:`22069`: [Doc] Fix typo in ``units.py`` documentation example
* :ghpull:`22067`: Backport PR #22064 on branch v3.5.x (DOC: Clarify y parameter in Axes.set_title)
* :ghpull:`22064`: DOC: Clarify y parameter in Axes.set_title
* :ghpull:`22049`: Backport PR #22048 on branch v3.5.x (Document how to prevent TeX from treating ``&``, ``#`` as special.)
* :ghpull:`22048`: Document how to prevent TeX from treating ``&``, ``#`` as special.
* :ghpull:`22047`: Backport PR #22044 on branch v3.5.x (Get correct source code link for decorated functions)
* :ghpull:`22044`: Get correct source code link for decorated functions
* :ghpull:`22024`: Backport PR #22009 on branch v3.5.x (FIX: Prevent set_alpha from changing color of legend patch)
* :ghpull:`22009`: FIX: Prevent set_alpha from changing color of legend patch
* :ghpull:`22019`: Backport PR #22018 on branch v3.5.x (BUG: fix handling of zero-dimensional arrays in cbook._reshape_2D)
* :ghpull:`22018`: BUG: fix handling of zero-dimensional arrays in cbook._reshape_2D
* :ghpull:`21996`: Backport PR #21990 on branch v3.5.x (Fix rubberbanding on wx+py3.10.)
* :ghpull:`21990`: Fix rubberbanding on wx+py3.10.
* :ghpull:`21987`: Backport PR #21862 on branch v3.5.x (DOC: Simplify markevery demo)
* :ghpull:`21969`: Backport PR #21948 on branch v3.5.x (Distinguish AbstractMovieWriter and MovieWriter in docs.)
* :ghpull:`21948`: Distinguish AbstractMovieWriter and MovieWriter in docs.
* :ghpull:`21953`: Backport PR #21946 on branch v3.5.x (DOC: fix interactive to not put Event Handling and Interactive Guide …)
* :ghpull:`21946`: DOC: fix interactive to not put Event Handling and Interactive Guide …

Issues (61):

* :ghissue:`22954`: [Doc]: v3.5.1 github stats are missing
* :ghissue:`22959`: [MNT]: macos-latest memory leak over threshold
* :ghissue:`22921`: [Bug]: Regression in animation from #22175
* :ghissue:`22908`: [Bug]: QuadMesh get_cursor_data errors if no array is set
* :ghissue:`21901`: Suggested clarification of comments in errorbar helpers
* :ghissue:`22932`: [Doc]: small edits to the Pull request guidelines
* :ghissue:`22858`: [Bug]: FigureCanvasTkAgg call creates memory leak
* :ghissue:`20490`: Memory leaks on matplotlib 3.4.2 (and 3.4.0)
* :ghissue:`22900`: [Doc]:  Typo in triage acknowledgment
* :ghissue:`22341`: [Bug]: GridSpec or related change between 3.4.3 and 3.5.1
* :ghissue:`22472`: [Bug]: ConciseDateFormatter not showing year anywhere when plotting <12 months
* :ghissue:`22874`: [Bug]: Textbox doesn't accept input
* :ghissue:`21893`: [Bug]: ``backend_pdf`` gives ``TTLibError`` with ``pdf.fonttype : 42``
* :ghissue:`22840`: [Bug]: Blank output EPS file when using latex and figure.autolayout = True
* :ghissue:`22762`: [Bug]: Issue with find_nearest_contour in contour.py
* :ghissue:`22823`: [Bug]: Changing Linestyle in plot window swaps some plotted lines
* :ghissue:`22804`: [Bug]: Quiver not working with subfigure?
* :ghissue:`22673`: [Bug]: tight_layout (version 3.5+)
* :ghissue:`21930`: [Bug]: EPS savefig messed up by 'figure.autolayout' rcParam on 3.5.0
* :ghissue:`22753`: windows CI broken on azure
* :ghissue:`22088`: [Bug]: Tool Manager example broken
* :ghissue:`22624`: [Bug]: invalid value encountered with 'ortho' projection mode
* :ghissue:`22640`: [Bug]: Confusing deprecation warning when empty data passed to axis with category units
* :ghissue:`22137`: [Bug]: Cannot clear figure of subfigures
* :ghissue:`22706`: [Bug]: RangeSlider.set_val does not move the slider (only poly and value)
* :ghissue:`22727`: MAtplolib pan and zoom dead slow on new PC
* :ghissue:`22687`: [Bug]: Empty text or text with a newline at either end + path_effects crashes
* :ghissue:`22694`: Revert set_show_cursor_data
* :ghissue:`22520`: [Bug]: Slow lasso selector over QuadMesh collection
* :ghissue:`22648`: Add packaging to setup_requires?
* :ghissue:`22052`: [Bug]: invert_yaxis function cannot invert the "over value" in colorbar axes
* :ghissue:`22576`: [Bug]: ``inset_axes`` colorbar + ``tight_layout`` raises ``AttributeError``
* :ghissue:`22590`: [Bug]: ValueError: Do not know how to convert "list" to dashes; when using axes errorbar.
* :ghissue:`21998`: [Bug]: Working with PyQt5, the different import order will make different result.
* :ghissue:`22330`: [Bug]: possible regression with pandas 1.4 with plt.plot when using a single column dataframe as the x argument
* :ghissue:`22125`: [Bug]: ``plt.plot`` thinks ``pandas.Series`` is 2-dimensional when nullable data type is used
* :ghissue:`22378`: [Bug]: TkAgg fails to find Tcl/Tk libraries in Windows for processes with a large number of modules loaded
* :ghissue:`22577`: [Bug]: Erroneous deprecation warning help message
* :ghissue:`21798`: [Bug]: Unhandled _get_renderer.Done exception in wxagg backend
* :ghissue:`22532`: [Issue]: Manually placing contour labels using ``clabel`` not working
* :ghissue:`22470`: [Bug]: Subsequent scatter plots work incorrectly
* :ghissue:`22471`: [Bug]: formlayout fails on PyQt6 due to the unqualified enum ShowAlphaChannel in class ColorButton
* :ghissue:`22473`: [Bug]: Secondary axis does not accept python builtins for transform
* :ghissue:`22384`: [Bug]: Curve styles gets mixed up when edited in the Curves Tab of Figure Options (Edit Axis)
* :ghissue:`22028`: [Bug]: mpl with py3.10.1 - Interactive figures - Constrain pan/zoom to x/y axis not work
* :ghissue:`13484`: Matplotlib keymap stop working after pressing tab
* :ghissue:`20130`: tk toolmanager add_toolitem fails to add tool to group other than the last one
* :ghissue:`21723`: [Bug]: Some styles trigger pcolormesh grid deprecation
* :ghissue:`22300`: [Bug]: Saving a fig with a colorbar using a ``TwoSlopeNorm`` sometimes results in 'posx and posy should be finite values'
* :ghissue:`22305`: [Bug]: Import Error in Matplotlib 3.5.1
* :ghissue:`21917`: [Bug]: pcolormesh is not responsive in Matplotlib 3.5
* :ghissue:`22094`: [Doc]: No documentation on ArtistList
* :ghissue:`21979`: [Doc]: Clarify default capstyle
* :ghissue:`22143`: [Bug]: ``constrained_layout`` merging similar subgrids
* :ghissue:`22131`: [Bug]: png icon image fails to load for manually defined tool buttons
* :ghissue:`22093`: [Bug]: AttributeError: 'AxesSubplot' object has no attribute 'add_text'
* :ghissue:`22085`: [Bug]: Memory leak with colorbar.make_axes
* :ghissue:`22065`: [Bug]: Additive offset with trailing zeros
* :ghissue:`15493`: common_texification misses & (ampersand)
* :ghissue:`22039`: [Doc]: [source] link for deprecated functions leads to _api/deprecation.py
* :ghissue:`22016`: [Bug]: matplotlib 3.3 changed how plt.hist handles iterables of zero-dimensional arrays.
